import os
from logging.config import fileConfig

# #3 Get connection string from env vars instead of a Git-committed env.py
# http://allan-simon.github.io/blog/posts/python-alembic-with-environment-variables/
# from sqlalchemy import engine_from_config
from sqlalchemy import engine_from_config, create_engine
from sqlalchemy import pool

from alembic import context

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = None

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def get_url():
    # #3 Get connection string from env vars instead of a Git-committed env.py
    # http://allan-simon.github.io/blog/posts/python-alembic-with-environment-variables/
    return "%s://%s:%s@%s/%s" % (
        os.getenv("DB_DIALECTDRIVER", "mysql"),
        os.getenv("DB_USER", "kodi-timekeeper"),
        os.getenv("DB_PASSWORD", "kodi-timekeeper"),
        os.getenv("DB_HOST", "localhost"),
        os.getenv("DB_NAME", "kodi-timekeeper"),
    )


def run_migrations_offline():
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    # #3 Get connection string from env vars instead of a Git-committed env.py
    # http://allan-simon.github.io/blog/posts/python-alembic-with-environment-variables/
    # url = config.get_main_option("sqlalchemy.url")
    url = get_url()
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    # #3 Get connection string from env vars instead of a Git-committed env.py
    # http://allan-simon.github.io/blog/posts/python-alembic-with-environment-variables/
    connectable = create_engine(get_url())

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
